pub trait AnalysisLoader: Sized {
// Required methods
fn needs_hard_reload(&self, path_prefix: &Path) -> bool;
fn fresh_host(&self) -> AnalysisHost<Self>;
fn set_path_prefix(&mut self, path_prefix: &Path);
fn abs_path_prefix(&self) -> Option<PathBuf>;
fn search_directories(&self) -> Vec<SearchDirectory>;
}Expand description
Allows to specify from where and which analysis files will be considered when reloading data to lower.
Required Methods
fn needs_hard_reload(&self, path_prefix: &Path) -> bool
fn fresh_host(&self) -> AnalysisHost<Self>
fn set_path_prefix(&mut self, path_prefix: &Path)
fn abs_path_prefix(&self) -> Option<PathBuf>
Sourcefn search_directories(&self) -> Vec<SearchDirectory>
fn search_directories(&self) -> Vec<SearchDirectory>
Returns every directory in which analysis files are to be considered.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".